==> glibc_1.92-1.tar.gz: glibc-1.92/libio/iofflush.c <==
/*
Copyright (C) 1993, 1995 Free Software Foundation

This file is part of the GNU IO Library.  This library is free
software; you can redistribute it and/or modify it under the
terms of the GNU General Public License as published by the
Free Software Foundation; either version 2, or (at your option)
any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this library; see the file COPYING.  If not, write to the Free
Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

As a special exception, if you link this library with files
compiled with a GNU compiler to produce an executable, this does not cause
the resulting executable to be covered by the GNU General Public License.
This exception does not however invalidate any other reasons why
the executable file might be covered by the GNU General Public License. */

#include "libioP.h"

int
_IO_fflush (fp)
     register _IO_FILE *fp;
{
  if (fp == NULL)
    return _IO_flush_all ();
  else
    {
      int result;
      _IO_flockfile (fp);
      CHECK_FILE (fp, EOF);
      result = _IO_SYNC (fp) ? EOF : 0;
      _IO_funlockfile (fp);
      return result;
    }
}

weak_alias (_IO_fflush, fflush)

#ifdef _IO_MTSAFE_IO
weak_alias (_IO_fflush, fflush_locked)
#endif

==> glibc-2.0.7pre3.tar.gz: glibc-2.0.7/libio/iofflush.c <==
/*
Copyright (C) 1993, 1995, 1996 Free Software Foundation, Inc.

This file is part of the GNU IO Library.  This library is free
software; you can redistribute it and/or modify it under the
terms of the GNU General Public License as published by the
Free Software Foundation; either version 2, or (at your option)
any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this library; see the file COPYING.  If not, write to the Free
Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

As a special exception, if you link this library with files
compiled with a GNU compiler to produce an executable, this does not cause
the resulting executable to be covered by the GNU General Public License.
This exception does not however invalidate any other reasons why
the executable file might be covered by the GNU General Public License. */

#include "libioP.h"
#include <stdio.h>

int
_IO_fflush (fp)
     register _IO_FILE *fp;
{
  if (fp == NULL)
    return _IO_flush_all ();
  else
    {
      int result;
      CHECK_FILE (fp, EOF);
      _IO_cleanup_region_start ((void (*) __P ((void *))) _IO_funlockfile, fp);
      _IO_flockfile (fp);
      result = _IO_SYNC (fp) ? EOF : 0;
      _IO_cleanup_region_end (1);
      return result;
    }
}

weak_alias (_IO_fflush, fflush)

#ifdef _IO_MTSAFE_IO
weak_alias (_IO_fflush, fflush_locked)
#endif
